@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2024 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -26,6 +26,8 @@ except ImportError:
 from apptools.preferences.api import Preferences
 from apptools.preferences.api import bind_preference
 from apptools.preferences.api import set_default_preferences
+from apptools._testing.optional_dependencies import requires_configobj
+
 from traits.api import Bool, HasTraits, Int, Float, Str, TraitError
 from traits.observation.api import match
 
@@ -43,6 +45,7 @@ def listener(event):
     listener.new = event.new
 
 
+@requires_configobj
 class PreferenceBindingTestCase(unittest.TestCase):
     """ Tests for preference bindings. """
 
