@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2024 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -23,6 +23,7 @@ except ImportError:
     from importlib_resources import files
 
 # Enthought library imports.
+from apptools._testing.optional_dependencies import requires_configobj
 from apptools.preferences.api import Preferences
 
 
@@ -30,6 +31,7 @@ from apptools.preferences.api import Preferences
 PKG = "apptools.preferences.tests"
 
 
+@requires_configobj
 class PreferencesTestCase(unittest.TestCase):
     """ Tests for preferences nodes. """
 
