@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2024 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -26,6 +26,8 @@ except ImportError:
 from apptools.preferences.api import Preferences, PreferencesHelper
 from apptools.preferences.api import ScopedPreferences
 from apptools.preferences.api import set_default_preferences
+from apptools._testing.optional_dependencies import requires_configobj
+
 from traits.api import (
     Any, Bool, HasTraits, Int, Float, List, Str, TraitError,
     push_exception_handler, pop_exception_handler,
@@ -53,6 +55,7 @@ def bgcolor_listener(event):
 PKG = "apptools.preferences.tests"
 
 
+@requires_configobj
 class PreferencesHelperTestCase(unittest.TestCase):
     """ Tests for the preferences helper. """
 
@@ -411,7 +414,9 @@ class PreferencesHelperTestCase(unittest.TestCase):
     def test_scoped_preferences(self):
         """ scoped preferences """
 
-        p = set_default_preferences(ScopedPreferences())
+        p = set_default_preferences(
+            ScopedPreferences(application_preferences_filename=self.tmpfile)
+        )
 
         # Set a preference value in the default scope.
         p.set("default/acme.ui.bgcolor", "blue")
@@ -602,3 +607,26 @@ class PreferencesHelperTestCase(unittest.TestCase):
         # attempt to create instance from invalid value
         with self.assertRaises(TraitError):
             AcmeUIPreferencesHelper(preferences_path="acme.ui")
+
+    def test_preferences_not_written_on_helper_creation(self):
+
+        class AppPreferencesHelper(PreferencesHelper):
+            #: The node that contains the preferences.
+            preferences_path = "app"
+
+            #: The user's favourite colour
+            color = Str()
+
+        default_preferences = Preferences(name="default")
+        default_preferences.set("app.color", "red")
+
+        application_preferences = Preferences(name="application")
+        preferences = ScopedPreferences(
+            scopes=[application_preferences, default_preferences]
+        )
+        self.assertIsNone(application_preferences.get("app.color"))
+
+        # Then creation of the helper should not cause the application
+        # preferences to change.
+        AppPreferencesHelper(preferences=preferences)
+        self.assertIsNone(application_preferences.get("app.color"))
